==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/ec2transitgateway/kotlin/inputs/GetConnectPeerFilter.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2transitgateway.kotlin.inputs

import com.pulumi.aws.ec2transitgateway.inputs.GetConnectPeerFilter.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property name Name of the filter.
 * @property values List of one or more values for the filter.
 */
public data class GetConnectPeerFilter(
    public val name: String,
    public val values: List<String>,
) : ConvertibleToJava<com.pulumi.aws.ec2transitgateway.inputs.GetConnectPeerFilter> {
    override fun toJava(): com.pulumi.aws.ec2transitgateway.inputs.GetConnectPeerFilter =
        com.pulumi.aws.ec2transitgateway.inputs.GetConnectPeerFilter.builder()
            .name(name.let({ args0 -> args0 }))
            .values(values.let({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [GetConnectPeerFilter].
 */
@PulumiTagMarker
public class GetConnectPeerFilterBuilder internal constructor() {
    private var name: String? = null

    private var values: List<String>? = null

    /**
     * @param value Name of the filter.
     */
    @JvmName("uxclbsjbrwqlpagk")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value List of one or more values for the filter.
     */
    @JvmName("vmxsxkqsbghnrdvp")
    public suspend fun values(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.values = mapped
    }

    /**
     * @param values List of one or more values for the filter.
     */
    @JvmName("heaeicoljnklbaeh")
    public suspend fun values(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.values = mapped
    }

    internal fun build(): GetConnectPeerFilter = GetConnectPeerFilter(
        name = name ?: throw PulumiNullFieldException("name"),
        values = values ?: throw PulumiNullFieldException("values"),
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/ec2transitgateway/kotlin/inputs/GetConnectPeerFilter.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2transitgateway.kotlin.inputs

import com.pulumi.aws.ec2transitgateway.inputs.GetConnectPeerFilter.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property name Name of the filter.
 * @property values List of one or more values for the filter.
 */
public data class GetConnectPeerFilter(
    public val name: String,
    public val values: List<String>,
) : ConvertibleToJava<com.pulumi.aws.ec2transitgateway.inputs.GetConnectPeerFilter> {
    override fun toJava(): com.pulumi.aws.ec2transitgateway.inputs.GetConnectPeerFilter =
        com.pulumi.aws.ec2transitgateway.inputs.GetConnectPeerFilter.builder()
            .name(name.let({ args0 -> args0 }))
            .values(values.let({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [GetConnectPeerFilter].
 */
@PulumiTagMarker
public class GetConnectPeerFilterBuilder internal constructor() {
    private var name: String? = null

    private var values: List<String>? = null

    /**
     * @param value Name of the filter.
     */
    @JvmName("qavvgvclvexpvssp")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value List of one or more values for the filter.
     */
    @JvmName("obqmwgxourlcxpho")
    public suspend fun values(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.values = mapped
    }

    /**
     * @param values List of one or more values for the filter.
     */
    @JvmName("fiqskpylvbdynhqy")
    public suspend fun values(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.values = mapped
    }

    internal fun build(): GetConnectPeerFilter = GetConnectPeerFilter(
        name = name ?: throw PulumiNullFieldException("name"),
        values = values ?: throw PulumiNullFieldException("values"),
    )
}
